# Authors

The helanal MDAKit was created by Fiona Naughton in 2024 from the 
MDAnalysis.analysis.helix_analysis module by Lily Wang, in turn 
based on the original helanal module, writen by Ben Hall.


All contributing authors are listed in this file below.
The repository history at https://github.com/MDAnalysis/helanal
and the CHANGELOG show individual code contributions.

## Chronological list of authors

<!--
The rules for this file:
  * Authors are sorted chronologically, earliest to latest
  * Please format it each entry as "Preferred name <GitHub username>"
  * Your preferred name is whatever you wish to go by --
    it does *not* have to be your legal name!
  * Please start a new section for each new year
  * Don't ever delete anything
-->

**2011**
- Ben Hall
- Oliver Beckstein <@orbeckst>

**2012**
- Sebastien Buchoux <@seb-buch>

**2013**
- Daniel Parton <@danielparton>
- Xavier Duepi <@xdeupi>

**2014**
- Tyler Reddy <@tylerjereddy>

**2015**
- David Dotson <@dotsdl>

**2020**
- Lily Wang <@lilyminium>
- Philip Loche <@PicoCentauri>

**2021**
- Estephania Barreto-Ojeda 

**2022**
- <@robotjellyzone>

**2024**
- Fiona Naughton <@fiona-naughton>
